
#include "galil1800_io.h"

/* Read max len bytes from the read fifo */
ssize_t galil1800_recv(struct galil1800_state *s, char *buf, ssize_t len)
{
	int count;

	if (!__galil1800_may_read(s))
		return 0;

	count = 0;
	do {
		*buf++ = inb(GALIL1800_READ_REG(s));
		++count;
	} while(count < len && galil1800_may_read(s));

	return count;
}

/* write max len bytes to the write fifo */
ssize_t galil1800_send(struct galil1800_state *s, const char *buf, size_t len)
{
	size_t count = len;
	int i, burst;
	const char *p = buf;

	burst = __galil1800_may_write(s);

	if(!count || !burst)
		return 0;

	if(burst == 2) {
		do {
			burst = count > GALIL1800_HALF_FULL_WRITE_BURST ?
				GALIL1800_HALF_FULL_WRITE_BURST : count;

			for (i=0; i < burst; ++i, ++p)
				outb_p(*p, GALIL1800_WRITE_REG(s));

			count -= burst;

		} while(count && galil1800_may_write(s) == 2);
	}

	while(count && galil1800_may_write(s)) {
		outb(*p, GALIL1800_WRITE_REG(s));
		--count;
		++p;
	}

	return len-count;
}

